ClapErrorWrapper

Struct ClapErrorWrapper 

pub struct ClapErrorWrapper { /* private fields */ }
A wrapper for clap::Error that implements UError

Contains a custom error code. When Display::fmt is called on this struct the clap::Error will be printed directly to stdout or stderr. This is because clap only supports colored output when it prints directly.

ClapErrorWrapper is generally created by calling the UClapError::with_exit_code method on clap::Error or using the From implementation from clap::Error to Box<dyn UError>, which constructs a ClapErrorWrapper with an exit code of 1.

use uucore::error::{ClapErrorWrapper, UError, UClapError};
let command = clap::Command::new("test");
let result: Result<_, ClapErrorWrapper> = command.try_get_matches().with_exit_code(125);

let command = clap::Command::new("test");
let result: Result<_, Box<dyn UError>> = command.try_get_matches().map_err(Into::into);