pub struct ExitCode(pub i32);Expand description
A special error type that does not print any message when returned from
uumain. Especially useful for porting utilities to using UResult.
There are two ways to construct an ExitCode:
use uucore::error::{ExitCode, UResult};
// Explicit
let res: UResult<()> = Err(ExitCode(1).into());
// Using into on `i32`:
let res: UResult<()> = Err(1.into());This type is especially useful for a trivial conversion from utils returning i32 to
returning UResult.
Tuple Fields
0: i32Implementations