get_utility_is_second_arg

Function get_utility_is_second_arg 

pub fn get_utility_is_second_arg() -> bool
Used to check if the utility is the second argument. Used to check if we were called as a multicall binary (coreutils <utility>)