pub fn set_utility_is_second_arg()Expand description
Change the value of UTILITY_IS_SECOND_ARG to true
Used to specify that the utility is the second argument.
pub fn set_utility_is_second_arg()Change the value of UTILITY_IS_SECOND_ARG to true
Used to specify that the utility is the second argument.