#[repr(u8)]pub enum LineEnding {
Newline = 10,
Nul = 0,
}Expand description
Line ending of either \n or \0
Used by various utilities that have the option to separate lines by nul
characters instead of \n. Usually, this is specified with the -z or
--zero flag.
The Display implementation writes the character corresponding to the
variant to the formatter.
Variants
Implementations
Sourceimpl LineEnding
impl LineEnding
Sourcepub fn from_zero_flag(is_zero_terminated: bool) -> Self
pub fn from_zero_flag(is_zero_terminated: bool) -> Self
Create a LineEnding from a -z/--zero flag
If is_zero_terminated is true, LineEnding::Nul is returned,
otherwise LineEnding::Newline.