DirFd

Struct DirFd 

pub struct DirFd { /* private fields */ }
A directory file descriptor that enables safe traversal

Implementations

Source

impl DirFd

pub fn open(path: &Path, symlink_behavior: SymlinkBehavior) -> Result<Self>

Open a directory and return a file descriptor

Arguments
  • path - The path to the directory to open
  • symlink_behavior - Whether to follow symlinks when opening
pub fn open_subdir( &self, name: &OsStr, symlink_behavior: SymlinkBehavior, ) -> Result<Self>

Open a subdirectory relative to this directory

Arguments
  • name - The name of the subdirectory to open
  • symlink_behavior - Whether to follow symlinks when opening
pub fn stat_at( &self, name: &OsStr, symlink_behavior: SymlinkBehavior, ) -> Result<FileStat>

Get raw stat data for a file relative to this directory

pub fn metadata_at( &self, name: &OsStr, symlink_behavior: SymlinkBehavior, ) -> Result<Metadata>

Get metadata for a file relative to this directory

pub fn metadata(&self) -> Result<Metadata>

Get metadata for this directory

pub fn fstat(&self) -> Result<FileStat>

Get raw stat data for this directory

pub fn read_dir(&self) -> Result<Vec<OsString>>

Read directory entries

Remove a file or empty directory relative to this directory

pub fn chown_at( &self, name: &OsStr, uid: Option<u32>, gid: Option<u32>, symlink_behavior: SymlinkBehavior, ) -> Result<()>

Change ownership of a file relative to this directory Use uid/gid of None to keep the current value

pub fn fchown(&self, uid: Option<u32>, gid: Option<u32>) -> Result<()>

Change ownership of this directory

pub fn chmod_at( &self, name: &OsStr, mode: u32, symlink_behavior: SymlinkBehavior, ) -> Result<()>

Change mode of a file relative to this directory

pub fn fchmod(&self, mode: u32) -> Result<()>

Change mode of this directory

pub fn mkdir_at(&self, name: &OsStr, mode: u32) -> Result<()>

Create a directory relative to this directory

pub fn open_file_at(&self, name: &OsStr) -> Result<File>

Open a file for writing relative to this directory Creates the file if it doesn’t exist, truncates if it does

pub fn from_raw_fd(fd: RawFd) -> Result<Self>

Create a DirFd from an existing file descriptor (takes ownership)