pub fn read_login_records() -> UResult<Vec<SystemdLoginRecord>>Expand description
Read login records from systemd-logind using safe wrapper functions This matches the approach used by GNU coreutils read_utmp_from_systemd()
pub fn read_login_records() -> UResult<Vec<SystemdLoginRecord>>Read login records from systemd-logind using safe wrapper functions This matches the approach used by GNU coreutils read_utmp_from_systemd()