pub fn format_system_time<W: Write>(
out: &mut W,
time: SystemTime,
fmt: &str,
mode: FormatSystemTimeFallback,
) -> UResult<()>Expand description
Format a SystemTime according to given fmt, and append to vector out.
pub fn format_system_time<W: Write>(
out: &mut W,
time: SystemTime,
fmt: &str,
mode: FormatSystemTimeFallback,
) -> UResult<()>Format a SystemTime according to given fmt, and append to vector out.