pub struct ClapErrorWrapper { /* private fields */ }Expand description
A wrapper for clap::Error that implements UError
Contains a custom error code. When Display::fmt is called on this struct
the clap::Error will be printed directly to stdout or stderr.
This is because clap only supports colored output when it prints directly.
ClapErrorWrapper is generally created by calling the
UClapError::with_exit_code method on clap::Error or using the From
implementation from clap::Error to Box<dyn UError>, which constructs
a ClapErrorWrapper with an exit code of 1.
use uucore::error::{ClapErrorWrapper, UError, UClapError};
let command = clap::Command::new("test");
let result: Result<_, ClapErrorWrapper> = command.try_get_matches().with_exit_code(125);
let command = clap::Command::new("test");
let result: Result<_, Box<dyn UError>> = command.try_get_matches().map_err(Into::into);Trait Implementations
Sourceimpl Debug for ClapErrorWrapper
impl Debug for ClapErrorWrapper
Sourceimpl Display for ClapErrorWrapper
impl Display for ClapErrorWrapper
Sourceimpl Error for ClapErrorWrapper
impl Error for ClapErrorWrapper
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl UClapError<ClapErrorWrapper> for Error
impl UClapError<ClapErrorWrapper> for Error
Sourcefn with_exit_code(self, code: i32) -> ClapErrorWrapper
fn with_exit_code(self, code: i32) -> ClapErrorWrapper
Set the exit code for the program if
uumain returns Ok(()).Auto Trait Implementations
impl !Freeze for ClapErrorWrapper
impl !RefUnwindSafe for ClapErrorWrapper
impl Send for ClapErrorWrapper
impl !Sync for ClapErrorWrapper
impl Unpin for ClapErrorWrapper
impl UnsafeUnpin for ClapErrorWrapper
impl !UnwindSafe for ClapErrorWrapper